Citing sospice
===============

If you use ``sospice`` in your work, we would appreciate acknowledging
it in your publications.

Please add the following line in your methods, conclusion or
acknowledgements section:

   This research used the open source ``sospice`` Python package.
